@@ -15,7 +15,8 @@ import sys
 from trigger.tacacsrc import Tacacsrc, get_device_password, convert_tacacsrc
 from trigger.utils.cli import yesno
 
-if not yesno('This will overwrite your .tacacsrc.gpg and all gnupg configuration, are you sure?'):
+prompt = 'This will overwrite your .tacacsrc.gpg and all gnupg configuration, are you sure?'
+if not yesno(prompt):
     sys.exit(1)
 
 (username, err, uid, gid, name, homedir, shell) = pwd.getpwuid(os.getuid())
@@ -32,8 +33,8 @@ Comment: First Last
 
 os.system('gpg --gen-key')
 
-if yesno('Would you like to convert your OLD tacacsrc configuration file to your new one?')
-        and os.path.isfile(homedir+'/.tacacsrc')
+prompt2 = 'Would you like to convert your OLD tacacsrc configuration file to your new one?'
+if yesno(prompt2) and os.path.isfile(os.path.join(homedir, '.tacacsrc')):
     convert_tacacsrc()
 else:
     print "Old tacacsrc not converted."
